@@ -95,17 +95,11 @@ pub fn publish_workspace(dir: &Path, version: &Version) {
 
     let graph = update_member_deps(dir, version);
 
-    let mut cfg = Config::default().unwrap();
-    cfg.set_values(cfg.load_values().unwrap()).unwrap();
-    cfg.load_credentials().unwrap();
-    let workspace = Workspace::new(&dir.clone().join("Cargo.toml"), &cfg).unwrap();
-
     let mut already_published: HashSet<String> = HashSet::new();
     dbg!(&graph);
     for current_package in graph.keys() {
         publish_crate(
-            &workspace,
-            &cfg,
+            dir,
             current_package,
             &graph,
             &mut already_published,
@@ -114,25 +108,30 @@ pub fn publish_workspace(dir: &Path, version: &Version) {
 }
 
 fn publish_crate(
-    workspace: &Workspace,
-    cfg: &Config,
+    dir: &Path,
     current_package: &str,
     all_packages: &HashMap<String, HashSet<String>>,
     already_published: &mut HashSet<String>,
 ) {
+    let mut cfg = Config::default().unwrap();
+    cfg.set_values(cfg.load_values().unwrap()).unwrap();
+    cfg.load_credentials().unwrap();
+
+    let workspace = Workspace::new(&dir.clone().join("Cargo.toml"), &cfg).unwrap();
+
     if already_published.contains(current_package) {
         return;
     }
     // publish all the local dependencies first
     for local_dep in all_packages.get(current_package).unwrap() {
         if !already_published.contains(local_dep) {
-            publish_crate(workspace, cfg, local_dep, all_packages, already_published);
+            publish_crate(dir, local_dep, all_packages, already_published);
         }
     }
 
     retry_with_index(delay::Fibonacci::from_millis(3000), |current_try| {
         match cargo::ops::publish(
-            workspace,
+            &workspace,
             &PublishOpts {
                 token: None,
                 config: &cfg,
